diff mbox series

[1/2] object: allow clear_commit_marks_all() to handle any repo

Message ID f8cce944-a094-6097-39c3-904f52e4b9f6@web.de (mailing list archive)
State New, archived
Headers show
Series [1/2] object: allow clear_commit_marks_all() to handle any repo | expand

Commit Message

René Scharfe Oct. 31, 2020, 12:21 p.m. UTC
Allow callers to specify the repository to use.  No functional change
intended.

Signed-off-by: René Scharfe <l.s.r@web.de>
---
 bisect.c           | 2 +-
 builtin/checkout.c | 2 +-
 builtin/gc.c       | 2 +-
 object.c           | 6 +++---
 object.h           | 5 +++--
 5 files changed, 9 insertions(+), 8 deletions(-)

--
2.29.2
diff mbox series

Patch

diff --git a/bisect.c b/bisect.c
index f5b1368128..ee7f7bd017 100644
--- a/bisect.c
+++ b/bisect.c
@@ -1090,7 +1090,7 @@  enum bisect_error bisect_next_all(struct repository *r, const char *prefix)
 		  nr), nr, steps_msg);
 	free(steps_msg);
 	/* Clean up objects used, as they will be reused. */
-	clear_commit_marks_all(ALL_REV_FLAGS);
+	clear_commit_marks_all(the_repository, ALL_REV_FLAGS);

 	return bisect_checkout(bisect_rev, no_checkout);
 }
diff --git a/builtin/checkout.c b/builtin/checkout.c
index 7c311cecb3..49d599a994 100644
--- a/builtin/checkout.c
+++ b/builtin/checkout.c
@@ -1042,7 +1042,7 @@  static void orphaned_commit_warning(struct commit *old_commit, struct commit *ne
 		describe_detached_head(_("Previous HEAD position was"), old_commit);

 	/* Clean up objects used, as they will be reused. */
-	clear_commit_marks_all(ALL_REV_FLAGS);
+	clear_commit_marks_all(the_repository, ALL_REV_FLAGS);
 }

 static int switch_branches(const struct checkout_opts *opts,
diff --git a/builtin/gc.c b/builtin/gc.c
index 2b99596ec8..4e3a904f70 100644
--- a/builtin/gc.c
+++ b/builtin/gc.c
@@ -788,7 +788,7 @@  static int should_write_commit_graph(void)

 	result = for_each_ref(dfs_on_ref, &data);

-	clear_commit_marks_all(SEEN);
+	clear_commit_marks_all(the_repository, SEEN);

 	return result;
 }
diff --git a/object.c b/object.c
index 3257518656..27cc72fc7c 100644
--- a/object.c
+++ b/object.c
@@ -453,12 +453,12 @@  void clear_object_flags(unsigned flags)
 	}
 }

-void clear_commit_marks_all(unsigned int flags)
+void clear_commit_marks_all(struct repository *r, unsigned int flags)
 {
 	int i;

-	for (i = 0; i < the_repository->parsed_objects->obj_hash_size; i++) {
-		struct object *obj = the_repository->parsed_objects->obj_hash[i];
+	for (i = 0; i < r->parsed_objects->obj_hash_size; i++) {
+		struct object *obj = r->parsed_objects->obj_hash[i];
 		if (obj && obj->type == OBJ_COMMIT)
 			obj->flags &= ~flags;
 	}
diff --git a/object.h b/object.h
index 20b18805f0..eccacc8bb8 100644
--- a/object.h
+++ b/object.h
@@ -191,8 +191,9 @@  void object_array_clear(struct object_array *array);
 void clear_object_flags(unsigned flags);

 /*
  * Clear the specified object flags from all in-core commit objects.
  */
-void clear_commit_marks_all(unsigned int flags);
+void clear_commit_marks_all(struct repository *r, unsigned int flags);

 #endif /* OBJECT_H */
@@ -191,8 +191,9 @@  void object_array_clear(struct object_array *array);

 /*
- * Clear the specified object flags from all in-core commit objects.
+ * Clear the specified object flags from all in-core commit objects from
+ * the specified repository.
  */